@@ -5,7 +5,18 @@ from mpl_toolkits.axes_grid1 import make_axes_locatable
 from matplotlib.colors import TwoSlopeNorm, ListedColormap, BoundaryNorm
 from matplotlib_scalebar.scalebar import ScaleBar
 
-def show_fig(image, title, color, ctitle, bounds=None, res=None, vmin=None, vmax=None):
+def show_fig(image, title, color, ctitle, bounds=None, res=None, vmin=None, vmax=None, savefig=False):
+    """
+	Plotting a raster file
+		image: input array (array-like) (e.g. rasterio.open('raster.tif').read(1))
+		title: figure title (str) (e.g. 'velocity plot')
+		color: figure colormap (str) (e.g. 'Spectral', 'RdBu', etc)
+		ctitle: colorbar title (str) (e.g. 'm/yr')
+		bounds: raster plot bounds, input: (left, right, bottom, top) (floats) 
+		res: raster pixel resolution (int or float)
+		vmin, vmax: plot minimum and maximum (int or float)
+		savefig: If true, figure is saved as a .jpg in the current directory with the filename being the title input (boolean)
+    """
     fig, ax = plt.subplots(figsize=(12,6))
     c = ax.imshow(image, cmap=color, extent=bounds, vmin=vmin, vmax=vmax)
     if res != None:
@@ -13,9 +24,20 @@ def show_fig(image, title, color, ctitle, bounds=None, res=None, vmin=None, vmax
     fig.colorbar(c, label=ctitle)
     fig.suptitle(title)
     plt.show()
-    # fig.savefig(title + '.jpg', dpi=500) # to save the plot as a jpg image
+    if savefig == True:
+    	fig.savefig(title + '.jpg', dpi=500) # to save the plot as a jpg image
 
-def scatterplot(data, xtitle, ytitle, title, colors, labels, markers, xyLine=False, buff=100):
+def scatterplot(data, xtitle, ytitle, title, colors, labels, markers, xyLine=False, buff=100, savefig=False):
+    """
+	Create a scatterplot from data
+		data: input data (list of arrays of length 2) (e.g. [[0, 0, 0, 0], [1, 2, 3, 4]] or [[[0, 0, 0], [1, 2, 3]], [[1, 1, 1, 1], [1, 2, 3, 4]]])
+		xtitle, ytitle: axis titles (str)
+		colors: list of colors for each x-y scatterplot dataset (list of str, same length as data)
+		labels: legend label for data (list of str, same length as data) (e.g. ['label1', 'label2'])
+		markers: scatterplot marker (list of str, same length as data)
+		xyLine: to show the 1-to-1 line (boolean)
+		buff: buffer on axis limits (int or float)
+    """
     fig = plt.figure()
     ax = fig.add_subplot(111)
     plt.grid()
@@ -37,13 +59,24 @@ def scatterplot(data, xtitle, ytitle, title, colors, labels, markers, xyLine=Fal
     ax.set_xlim([min(minimums), max(maximums)])
     ax.set_ylim([min(minimums), max(maximums)])
     fig.suptitle(title, size=8)
-
-    figName = title.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
+    
+    if savefig == True:
+    	figName = title.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
 
 
 def plotMany(cbarTitle, color, plotTitle, *kwargs):
-    # All *kwargs should follow this: [data, title, v] where v is [vmin, vcenter, vmax]
+    """
+	Create a figure with many plots
+		cbarTitle: colorbar title (str)
+		color: colormap (str) (e.g. 'Spectral', 'RdBu', 'gist_earth')
+		plotTitle: title of the figure (str)
+	
+		All *kwargs should follow this: [data, title, v] where v is [vmin, vcenter, vmax]. (list of lists, on per plot)
+			data: array of data (array-like)
+			title: plot title (str)
+			v: minimum, center, and maximum value for plot colormap
+    """
     # plt.subplots([rows of plots], [columns of plots], figsize=([width], [height])
     l = len(kwargs[0]) + 3
     row, col = (int(l/4), 4)
@@ -69,12 +102,12 @@ def plotMany(cbarTitle, color, plotTitle, *kwargs):
     # EXAMPLE:
     # icepack_v_list = [np.array(np.sqrt(vx ** 2 + vy ** 2)) for vx, vy in zip(icepack_vx_list, icepack_vy_list)]
     # icepack_title_list = ['Icepack Velocity (n=' + str(n + 1) + ')' for n in range(l)]
-    # plotMany('Velocity (m/yr)', 'BrBG', 'Plot of All IcePack Results', 0, 5, 60,
-    #          list(zip(icepack_v_list, icepack_title_list)))
+    # minmax_list = [[0, 5, 60] for i in icepack_vx_list]
+    # plotMany('Velocity (m/yr)', 'BrBG', 'Plot of All IcePack Results', list(zip(icepack_v_list, icepack_title_list, minmax_list)))
 
 
 def elevationBinPlot(xVal1, yVal1, xVal2, yVal2, xLabel1, yLabel1, xLabel2, title1,
-                     elevationBinWidth, minVal, buff, alpha):
+                     elevationBinWidth, minVal, buff, alpha, savefig=False):
     '''
     Plot y (elevation bin) vs two x data sources: one primary one (xVal1) and a secondary bar graph (xVal2)
     :param xVal1: Primary x values (scatter plot)
@@ -111,13 +144,17 @@ def elevationBinPlot(xVal1, yVal1, xVal2, yVal2, xLabel1, yLabel1, xLabel2, titl
 
     fig.suptitle(title1, weight='bold')
     fig.tight_layout()
-    plt.show(block=False)
-    figName = title1.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = title1.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
 def elevationBinPlot2(xVal1, labx1, xVal1_2, labx1_2, yVal1, xVal2, yVal2, xLabel1, yLabel1, xLabel2, title1,
-                     elevationBinWidth, minVal, buff, alpha):
+                     elevationBinWidth, minVal, buff, alpha, savefig=False):
     '''
     Plot y (elevation bin) vs two x data sources: one primary one (xVal1) and a secondary bar graph (xVal2)
     :param xVal1: Primary x values (scatter plot)
@@ -159,10 +196,13 @@ def elevationBinPlot2(xVal1, labx1, xVal1_2, labx1_2, yVal1, xVal2, yVal2, xLabe
 
     fig.suptitle(title1, weight='bold')
     fig.tight_layout()
-    plt.show(block=False)
-    figName = title1.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = title1.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
 def elevationBinPlot3Subfigs(x_subp1, x_subp1_lab, x_subp1_2, x_subp1_lab_2, x_subp1_3, x_subp1_lab_3, y_subp1,
                              x2_subp1, y2_subp1, xLabel1, yLabel1, xLabel2, title1, elBinWidth, buff, alpha, title, res,
@@ -170,7 +210,7 @@ def elevationBinPlot3Subfigs(x_subp1, x_subp1_lab, x_subp1_2, x_subp1_lab_2, x_s
                              subp4, title4, cbar4, color4,
                              subp5, title5, cbar5, color5,
                              err_subp1_2=None, err_subp1_3=None,
-                             x_subp1_ref=None, x_subp1_lab_ref=None, y_subp1_ref=None, ref_var=None, cbar4ticks=None):
+                             x_subp1_ref=None, x_subp1_lab_ref=None, y_subp1_ref=None, ref_var=None, cbar4ticks=None, savefig=False):
     '''
     Plot y (elevation bin) vs two x data sources: one primary one (xVal1) and a secondary bar graph (xVal2)
     Includes 3 subplots showing a desired source: emergence velocity, thickness, speed
@@ -299,12 +339,15 @@ def elevationBinPlot3Subfigs(x_subp1, x_subp1_lab, x_subp1_2, x_subp1_lab_2, x_s
     fig.set_size_inches(12, 8)
     fig.tight_layout(pad=0.5, w_pad=-3.0, h_pad=2.0)
     fig.suptitle(title, weight='bold')
-    plt.show(block=False)
-    figName = title.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = title.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
-def plotData(dataVals, cbarTitle, color, plotTitle, cluster=None, quiver=None, colorbarMax=None):
+def plotData(dataVals, cbarTitle, color, plotTitle, cluster=None, quiver=None, colorbarMax=None, savefig=False):
     '''
     Plots a map from input values (array-like)
     :param dataVals: values to be plotted
@@ -335,14 +378,17 @@ def plotData(dataVals, cbarTitle, color, plotTitle, cluster=None, quiver=None, c
     ax.set_title(plotTitle, weight='bold', pad=10)
     fig.tight_layout(pad=3, w_pad=-3.0, h_pad=2.0)
 
-    plt.show(block=False)
-    figName = plotTitle.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = plotTitle.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
 def plotData3(dataVals1, cbarTitle1, color1, title1, dataVals2, cbarTitle2, color2, title2,
               dataVals3, cbarTitle3, color3, title3, plotTitle, res, quiver2=None, quiver3=None,
-              div_select=[0,0,0], min=[0,0,0], mean=[50,50,50], max=[100,100,100]):
+              div_select=[0,0,0], min=[0,0,0], mean=[50,50,50], max=[100,100,100], savefig=False):
     # div_select is to specify divnorm colorbar values for each of 3 plots or just have them be the data min, mean, max
     fig = plt.figure()
     ax1 = fig.add_subplot(131, label="1")
@@ -399,14 +445,17 @@ def plotData3(dataVals1, cbarTitle1, color1, title1, dataVals2, cbarTitle2, colo
     fig.set_size_inches(14, 4)
     fig.suptitle(plotTitle, weight='bold')
     fig.tight_layout(pad=3, w_pad=2.0, h_pad=0.0)
-    plt.show(block=False)
-    figName = plotTitle.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = plotTitle.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
 def plotData6(dataVals1, cbarTitle1, color1, title1, dataVals2, cbarTitle2, color2, title2,
               dataVals3, cbarTitle3, color3, title3, dataVals4, cbarTitle4, color4, title4,
-              dataVals5, cbarTitle5, color5, title5, dataVals6, cbarTitle6, color6, title6, plotTitle, res):
+              dataVals5, cbarTitle5, color5, title5, dataVals6, cbarTitle6, color6, title6, plotTitle, res, savefig=False):
     fig = plt.figure()
     ax1 = fig.add_subplot(231, label="1")
     ax2 = fig.add_subplot(232)
@@ -480,13 +529,16 @@ def plotData6(dataVals1, cbarTitle1, color1, title1, dataVals2, cbarTitle2, colo
     fig.set_size_inches(14, 8)
     fig.suptitle(plotTitle, weight='bold')
     fig.tight_layout(pad=3, w_pad=2.0, h_pad=0.0)
-    plt.show(block=False)
-    figName = plotTitle.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = plotTitle.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
 def plotDataPoints(dataVals1, cbarTitle1, color1, dataVals2, cbarTitle2, color2,
-                   plotTitle, pointx, pointy, pointlabels):
+                   plotTitle, pointx, pointy, pointlabels, savefig=False):
     '''
     Plots a map from input values (array-like) with labelled point locations from reference data
     Plots 2 side by side maps: identical but with difference basemaps (e.g. elevation and pixel mass balance)
@@ -527,10 +579,13 @@ def plotDataPoints(dataVals1, cbarTitle1, color1, dataVals2, cbarTitle2, color2,
 
     fig.suptitle(plotTitle, weight='bold')
     fig.tight_layout(pad=3, w_pad=0.0, h_pad=3.0)
-    plt.show(block=False)
-    figName = plotTitle.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = plotTitle.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
 def velPlot(vx, vy, v_tot, area, threshold):
     '''
@@ -576,7 +631,7 @@ def elevationBinPlot3data3Subfigs(x_subp1, x_subp1_lab, x_subp1_2, x_subp1_lab_2
                                   subp4, title4, cbar4, color4,
                                   subp5, title5, cbar5, color5,
                                   err_subp1_2=None, err_subp1_3=None, err_subp1_4=None,
-                                  x_subp1_ref=None, x_subp1_lab_ref=None, y_subp1_ref=None, ref_var=None, cbar4ticks=None):
+                                  x_subp1_ref=None, x_subp1_lab_ref=None, y_subp1_ref=None, ref_var=None, cbar4ticks=None, savefig=False):
     '''
     Same as elevationBinPlot3Subfigs (above) but includes comparison of 3 datasets in NW plot
     '''
@@ -694,12 +749,15 @@ def elevationBinPlot3data3Subfigs(x_subp1, x_subp1_lab, x_subp1_2, x_subp1_lab_2
     fig.set_size_inches(12, 8)
     fig.tight_layout(pad=0.5, w_pad=-3.0, h_pad=2.0)
     fig.suptitle(title, weight='bold')
-    plt.show(block=False)
-    figName = title.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = title.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
-def plotClassify(array, class_vals, class_labels, colors, title):
+def plotClassify(array, class_vals, class_labels, colors, title, savefig=False):
     # plot array of discrete values
     cmap = ListedColormap(colors)
 
@@ -711,12 +769,15 @@ def plotClassify(array, class_vals, class_labels, colors, title):
     ax.set_axis_off()
 
     plt.tight_layout()
-    plt.show(block=False)
-    figName = title.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = title.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
-def plotContinuous(array, range, cbar, title, cbarTitle, quiver=None):
+def plotContinuous(array, range, cbar, title, cbarTitle, quiver=None, savefig=False):
     # plot array of continuous values
     fig, ax = plt.subplots(figsize=(10, 5))
     colors = plt.cm.get_cmap(cbar).copy()
@@ -731,9 +792,12 @@ def plotContinuous(array, range, cbar, title, cbarTitle, quiver=None):
     ax.set(title=title)
     ax.set_axis_off()
     plt.tight_layout()
-    plt.show(block=False)
-    figName = title.replace(' ', '_') + '.png'
-    fig.savefig('Figures/' + figName, dpi=250)
-    # Image.open('Figures/' + figName).show()
+    if savefig == True:
+    	plt.show(block=False)
+    	figName = title.replace(' ', '_') + '.png'
+    	fig.savefig(figName, dpi=250)
+    	# Image.open(figName).show()
+    else:
+    	plt.show()
 
 
