@@ -26,6 +26,17 @@ import pandas as pd
 """ Simple way to plot raster file """
 
 def show_fig(image, title=None, color='Spectral', ctitle='colorbar title', bounds=None, res=None, vmin=None, vmax=None, savefig=False):
+    """
+	Plotting a raster file
+		image: input array (array-like) (e.g. rasterio.open('raster.tif').read(1))
+		title: figure title (str) (e.g. 'velocity plot')
+		color: figure colormap (str) (e.g. 'Spectral', 'RdBu', etc)
+		ctitle: colorbar title (str) (e.g. 'm/yr')
+		bounds: raster plot bounds, input: (left, right, bottom, top) (floats) 
+		res: raster pixel resolution (int or float)
+		vmin, vmax: plot minimum and maximum (int or float)
+		savefig: If true, figure is saved as a .jpg in the current directory with the filename being the title input (boolean)
+    """
     fig, ax = plt.subplots(figsize=(12,6))
     c = ax.imshow(image, cmap=color, extent=bounds, vmin=vmin, vmax=vmax)
     if res != None:
@@ -49,13 +60,28 @@ def show_fig(image, title=None, color='Spectral', ctitle='colorbar title', bound
 """
 
 def shpReprojection(shapefile, crs, dst='reprojected_shape.shp'):
+    """
+	Reproject a shapefile
+		shapefile: input shapefile path (str) (e.g. 'input_shapefile.shp')
+		crs: output coordinate system (str) (e.g. 'EPSG:4326')
+		dst: output filename (str) (e.g. 'output_shapefile.shp')
+    """
     src = gpd.read_file(shapefile)
     src = src.to_crs(crs)
     src.to_file(dst)
     
 
 def shpClip(geotiff, shapefile, destination, nan_val=0, fill=True, pad_size=0):
-    # clip a geotiff with a shapefile
+    """
+	Clip a geotiff with a shapefile
+		geotiff: input raster to clip (str) (e.g. 'input.tif')
+		shapefile: shapefile used for clipping (str) (e.g. 'input_shape.shp')
+		destination: output clipped raster filename (str) (e.g. 'output.tif')
+		nan_val: NaN value (int or float)
+		fill: If True, the pixels outside the features will be set to nan_val. If False, the output array will contain the original pixel data, and only the mask will be based on shapes (boolean) 
+		pad_size: width of padding in pixels (int or float)    
+    """
+    
     with rasterio.open(geotiff) as src:
         # we need to make a temporary shapefile with the same crs as the geotiff 
         shpReprojection(shapefile, src.crs, dst='temp.shp')
@@ -86,6 +112,15 @@ def shpClip(geotiff, shapefile, destination, nan_val=0, fill=True, pad_size=0):
 
 
 def tifReprojectionResample(file, reprojected_tif, crs, res, interp, extent_file=None):
+    """
+	Reproject, resample, and/or clip raster extent
+		file: input raster to resample, reproject, and/or clip (str) (e.g. 'input.tif')
+		reprojected_tif: output filename (str) (e.g. 'output_raster.tif')
+		crs: target raster coordinate system (str) (e.g. 'EPGS:4326')
+		res: target raster resolution (int or float)
+		interp: resampling interpolation method (Resampling method from rasterio.warp module)  (e.g. rasterio.warp.Resampling.cubic_spline)
+		extent_file: raster file to match extent (str)    
+    """
     with rasterio.open(file) as src:
         if extent_file is None:
             # keep initial file bounds
@@ -130,6 +165,13 @@ def tifReprojectionResample(file, reprojected_tif, crs, res, interp, extent_file
 
 
 def fillHole(file, dest='output_filled.tif', dist=10, iters=1):
+    """
+	Fill hole in raster
+		file: input raster to fill (str) (e.g. 'input.tif')
+		dest: output filename (str) (e.g. 'output_raster.tif')
+		dist: the maximum number of pixels to search in all directions to find values to interpolate from (int)
+		iters: the number of 3x3 smoothing filter passes to run (int)
+    """
     with rasterio.open(file) as src:
         profile = src.profile
         inputs = src.read(1)
@@ -146,7 +188,11 @@ def fillHole(file, dest='output_filled.tif', dist=10, iters=1):
 
 
 def mosaic_files(files, mosaic_output):
-    # create a mosiac of the obtained raster files. reproject files to the same crs if needed
+    """
+	Create a mosiac of the obtained raster files. reproject files to the same crs if needed
+		files: input rasters to mosaic (list of str) (e.g. ['input1.tif', 'input2.tif', 'input3.tif', 'input4.tif'])
+		mosaic_output: the number of 3x3 smoothing filter passes to run (int)
+    """
     src_files_to_mosaic = []
     dst_crs = rasterio.open(files[0]).crs
     for file in files:
@@ -166,6 +212,12 @@ def mosaic_files(files, mosaic_output):
 
 
 def rasterLike(array, destination, geotiff):
+    """
+	Save array as raster, assuming it is 'like' the raster (same res, crs, size, etc)
+		array: input array to save as a raster (array-like)
+		destination: output filename (str) (e.g. 'output_raster.tif')
+		geotiff: raster (str) (e.g. 'raster.tif)
+    """
     with rasterio.open(geotiff) as src:
         kwargs = src.meta.copy()
     with rasterio.open(destination, 'w', **kwargs) as dst:
